@@ -1,5 +1,5 @@
 //**************************************************************************
-//   Copyright (C) 2004, 2005 by Petri Damstn
+//   Copyright (C) 2004-2006 by Petri Damsten
 //   petri.damsten@iki.fi
 //
 //   This program is free software; you can redistribute it and/or modify
@@ -15,30 +15,34 @@
 //   You should have received a copy of the GNU General Public License
 //   along with this program; if not, write to the
 //   Free Software Foundation, Inc.,
-//   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+//   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 //**************************************************************************
 #ifndef SUBTITLEOPTIONS_H
 #define SUBTITLEOPTIONS_H
 
 #include <kmf_stddef.h>
-#include "subtitleoptionslayout.h"
 #include <qdvdinfo.h>
+#include <kmflanguagewidgets.h>
+#include "ui_subtitleoptions.h"
 
 /**
 @author Petri Damsten
 */
-class SubtitleOptions : public SubtitleOptionsLayout
+class SubtitleOptions : public KDialog, public Ui::SubtitleOptions
 {
     Q_OBJECT
   public:
-    SubtitleOptions(QWidget *parent = 0, const char *name = 0);
+    SubtitleOptions(QWidget *parent = 0);
     ~SubtitleOptions();
 
     void getData(QDVD::Subtitle& obj) const;
     void setData(const QDVD::Subtitle& obj);
 
   protected slots:
-    void okClicked();
+    virtual void accept();
+
+  private:
+    LanguageListModel m_languageModel;
 };
 
 #endif
