@@ -1,5 +1,5 @@
 //**************************************************************************
-//   Copyright (C) 2004, 2005 by Petri Damstn
+//   Copyright (C) 2004-2006 by Petri Damsten
 //   petri.damsten@iki.fi
 //
 //   This program is free software; you can redistribute it and/or modify
@@ -15,24 +15,24 @@
 //   You should have received a copy of the GNU General Public License
 //   along with this program; if not, write to the
 //   Free Software Foundation, Inc.,
-//   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+//   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 //**************************************************************************
 #ifndef SIZEWIDGET_H
 #define SIZEWIDGET_H
 
-#include <sizewidgetlayout.h>
+#include <ui_sizewidget.h>
 #include <stdint.h>
 
 /**
 	@author Petri Damsten <petri.damsten@iki.fi>
 */
 
-class SizeWidget : public SizeWidgetLayout
+class SizeWidget : public QWidget, public Ui::SizeWidget
 {
     Q_OBJECT
   public:
-    SizeWidget(QWidget* parent = 0, const char* name = 0, WFlags fl = 0);
-    ~SizeWidget();
+    SizeWidget(QWidget* parent = 0);
+    virtual ~SizeWidget();
 
     void setMax(uint64_t max) { m_max = max; update(); };
     void setSize(uint64_t size) { m_size = size; update(); };
