@@ -1,5 +1,5 @@
 //**************************************************************************
-//   Copyright (C) 2004, 2005 by Petri Damstn
+//   Copyright (C) 2004-2006 by Petri Damsten
 //   petri.damsten@iki.fi
 //
 //   This program is free software; you can redistribute it and/or modify
@@ -15,22 +15,23 @@
 //   You should have received a copy of the GNU General Public License
 //   along with this program; if not, write to the
 //   Free Software Foundation, Inc.,
-//   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+//   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 //**************************************************************************
 #ifndef TOOLPROPERTIES_H
 #define TOOLPROPERTIES_H
 
-#include "toolpropertieslayout.h"
+#include "ui_toolproperties.h"
 #include "tools.h"
 
-class ToolProperties: public ToolPropertiesLayout
+class ToolProperties: public KDialog, public Ui::ToolProperties
 {
     Q_OBJECT
   public:
-    ToolProperties(QWidget *parent = 0, const char *name = 0);
+    ToolProperties(QWidget *parent = 0);
+    virtual ~ToolProperties() {};
 
-    void setData(const QToolListItem& item);
-    void getData(QToolListItem* item);
+    void setData(const ToolItem& item);
+    void getData(ToolItem* item);
     void setReadOnly(bool readonly);
 };
 
